@@ -12,9 +12,9 @@ class PoolContainer(dict):
     # the default parameters of pool
     pool_default_params = {
         'pre_ping': True,
-        'echo': True,
-        'timeout': None,
-        'recycle': 60 * 60,
+        'echo': False,
+        'timeout': 30,
+        'recycle': 60 * 15,
         'pool_size': 10,
         'max_overflow': 10,
     }
@@ -33,4 +33,5 @@ class PoolContainer(dict):
 
 
 # the pool's container, for maintaining the pools
+# every process has it's own pool container
 pool_container = PoolContainer()
